(function (Drupal) {

  'use strict';

  /**
   * Write the template name preview to the DOM.
   *
   * @param {string} suggestionInput
   *   The input value of the suggestion field.
   */
  function updatePreview(suggestionInput) {
    // If the suggestion field is empty, use a default value.
    if (!suggestionInput || suggestionInput.length == 0) {
      suggestionInput = 'my_example_template';
    }

    // Update the preview per the suggestion input.
    document
      .querySelector('#template-block__name-preview')
      .textContent = suggestionInput.replaceAll('_', '-');
  }

  Drupal.behaviors.templateBlockNamePreview = {
    attach: function (context) {

      once('template-block-name-preview', '#template-block__suggestion-field', context)
        .forEach(function ($input) {

          // Update the preview on load.
          updatePreview($input.value);

          // Update the preview on keyup.
          $input.addEventListener('keyup', function() {
            updatePreview($input.value);
          });

        });

    }
  };

})(Drupal);
